import zipfile
import io
import sys
import os
import stat

import requests

os_driver_map = {
    "linux": "linux64",
    "linux2": "linux64",
    "darwin": "mac64",
    "win32": "win32",
    "cygwin": "win32"
}

def _get_zipfile_url_(version, driveros):
    return "https://chromedriver.storage.googleapis.com/{}/chromedriver_{}.zip".format(version, driveros)

def download_chromedriver(version="2.46"):
    try:
        driveros = os_driver_map[sys.platform] 
    except:
        raise Exception("Driver not compatible with OS")
    
    zip_file_url = _get_zipfile_url_(version, driveros)
    r = requests.get(zip_file_url)
    z = zipfile.ZipFile(io.BytesIO(r.content))
    z.extractall()
    os.chmod("./chromedriver", stat.S_IXUSR)



from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path
import re

here = path.abspath(path.dirname(__file__))

version = re.search(
    '^__version__\s*=\s*"(.*)"',
    open('AutoChromedriver/__init__.py').read(),
    re.M
    ).group(1)

# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
        name = 'AutoChromedriver',
        packages = ['AutoChromedriver'], # this must be the same as the name above
        version = version,
        description = 'Downloads and unzips chromedriver to curent directory',
        author = 'joeyism',
        author_email = 'joeyism101@gmail.com',
        url = 'https://github.com/joeyism/autochromedriver', # use the URL to the github repo
        download_url = 'https://github.com/joeyism/autochromedriver' + version + '.tar.gz',
        keywords = ['chromedriver', 'selenium', 'auto', 'automatic', 'download'], 
        classifiers = [],
        install_requires=['selenium'],
        )
